
# Rainbird AutoML

Create machine learning models using just the dataset and associated information about the data. Rainbird AutoML will ingest the data, light touch clean the data, capture statistics over the training data, before automating the steps required to transform, train, and fine tune numerous models based on a number of ML algorithms. The resulting model performances can be reviewed and predictions made against the chosen model. The model can receive batch prediction requests and can be deployed to dedicated cloud infrastructure.

## Authors

- [Nathan Roberts](https://github.com/nroberts1)


## Documentation

For demos and documentation see the [Rainbird Community](https://community.rainbird.ai/)
